@@ -25,7 +25,7 @@ class LineSegment2D(Base1DIn2D):
     __slots__ = ()
 
     def __init__(self, p, v):
-        """Initilize LineSegment2D."""
+        """Initialize LineSegment2D."""
         Base1DIn2D.__init__(self, p, v)
 
     @classmethod
@@ -55,7 +55,7 @@ class LineSegment2D(Base1DIn2D):
         """ Create a LineSegment2D from a nested array of two endpoint coordinates.
 
         Args:
-            line_arry: Nested tuples ((pt1.x, pt1.y), (pt2.x, pt2.y)), where
+            line_array: Nested tuples ((pt1.x, pt1.y), (pt2.x, pt2.y)), where
                 pt1 and pt2 represent the endpoints of the line segment.
         """
         return LineSegment2D.from_end_points(*tuple(Point2D(*pt) for pt in line_array))
@@ -85,6 +85,23 @@ class LineSegment2D(Base1DIn2D):
         """The length of the line segment."""
         return self.v.magnitude
 
+    def is_equivalent(self, other, tolerance):
+        """Boolean noting equivalence (within tolerance) between this line and another.
+
+        The order of the line points do not matter for equivalence to be true.
+
+        Args:
+            other: LineSegment2D for comparison.
+            tolerance: float representing point equivalence.
+
+        Returns:
+            True if equivalent else False
+        """
+        return (self.p1.is_equivalent(other.p1, tolerance) and
+                self.p2.is_equivalent(other.p2, tolerance)) or \
+               (self.p1.is_equivalent(other.p2, tolerance) and
+                self.p2.is_equivalent(other.p1, tolerance))
+
     def flip(self):
         """Get a copy of this line segment that is flipped."""
         return LineSegment2D(self.p2, self.v.reverse())
@@ -132,8 +149,8 @@ class LineSegment2D(Base1DIn2D):
 
         Args:
             distances: A list of distances along the line at which to subdivide it.
-                This can also be a single number that will be repeated unitl the end of
-                the line.
+                This can also be a single number that will be repeated until the
+                end of the line.
         """
         if isinstance(distances, (float, int)):
             distances = [distances]
@@ -244,4 +261,4 @@ class LineSegment2D(Base1DIn2D):
 
     def __repr__(self):
         return 'LineSegment2D (<%.2f, %.2f> to <%.2f, %.2f>)' % \
-            (self.p.x, self.p.y, self.p.x + self.v.x, self.p.y + self.v.y)
\ No newline at end of file
+            (self.p.x, self.p.y, self.p.x + self.v.x, self.p.y + self.v.y)
